% Run this script to compute the enzyme activities and to 
% plot the fluxes, free energies, and the activity ratios.

g1 = g(1:m);
g2 = g((m+1):(2*m));
c1 = exp((g1-go')./kT);
c2 = exp((g2-go')./kT);

dG1 = Srx'*g1;
dG2 = Srx'*g2;
dGo = Srx'*go';
% ANT transporter dependence on membrane potential:
dGo(39) = dGo(39) + go(46);
dG1(39) = dG1(39) + go(46);
dG2(39) = dG2(39) + go(46);
% pH dependence on Pi transport:
dG1(40) = dG1(40) + kT*log(c1(46));
dG2(40) = dG2(40) + kT*log(c2(46));
Keq = exp( - dGo ./ kT );

Srxp = Srx.*(Srx>0);
Srxn = -Srx.*(Srx<0);
cTr1 = prod((ones(n_int,1)*c1')'.^Srxp);
cTl1 = prod((ones(n_int,1)*c1')'.^Srxn);
cTr2 = prod((ones(n_int,1)*c2')'.^Srxp);
cTl2 = prod((ones(n_int,1)*c2')'.^Srxn);
cTr1(40) = cTr1(40)*c1(46);
cTr2(40) = cTr2(40)*c2(46);
h1 = (Keq.*cTl1' - cTr1');
h2 = (Keq.*cTl2' - cTr2');
icm = ((abs(dG1)>1e-6).*(abs(dG2)>1e-6));
X1 = max( icm.*J1(1:n_int)./h1, 1e-15);
X2 = max( icm.*J2(1:n_int)./h2, 1e-15);
% Since there is no estimate for X2(16) (both flux and
% potential are zero), we set X2(16) = X1(16):
X2(16) = X1(16);

f = (X1./X2);
for i = 1:n_int
  if icm(i) == 0
     f(i) = 1;
  end
end

ii = [];
for i = 1:n_int
  if (abs(J1(i)) > 1e-6) || (abs(J2(i)) > 1e-6)
    ii = [ii i];
  end
end
N = length(ii);
X = [];
Y = [];
for i = 1:N
  X = [X (i-0.5) (i+0.5)];
  Y = [Y f(ii(i)) f(ii(i))];
end

figure(1); clf; axes('position',[0.15 0.15 0.8 0.8]);
semilogy( X,Y,'k', 'linewidth', 2 );
set(gca,'Fontsize',18,'Xtick',1:n,'XtickLabel',[]);
set(gca,'Ytick',[1e-2 1e-1 1 1e1 1e2])
hold on;
for i = 1:N
  if f(ii(i)) > 10^(+0.25)
     p = semilogy([i i],[1 f(ii(i))],'linewidth',8); 
     set(p,'Color',[0.5 1 0.5]); 
  end
  if f(ii(i)) < 10^(-0.25)
     p = semilogy([i i],[f(ii(i)) (1)],'linewidth',8); 
     set(p,'Color',[0.5 0.5 1]); 
  end
end
semilogy( X,Y,'k', 'linewidth', 2 ); axis([0 (N+1) 1e-2 1e2]);
p = semilogy([20 25],[10^(3.52/2) 10^(3.52/2)],'linewidth',8); set(p,'Color',[0.5 1 0.5]);
p = semilogy([20 25],[10^(2.32/2) 10^(2.32/2)],'linewidth',8); set(p,'Color',[0.5 0.5 1]);
text(25.25,10^(3.52/2),'Glycogenesis Up/','Fontsize',13.5);
text(25.25,10^(3.08/2),'Glycogenolysis Down','Fontsize',13.5);
text(25.25,10^(2.32/2),'Glycogenesis Down/','Fontsize',13.5);
text(25.25,10^(1.88/2),'Glycogenolysis Up','Fontsize',13.5);
hold off
for i = 1:N
  t = text(i,10^(-4.1/2),genes(ii(i)),'Rotation',-90,...
      'Fontsize',8);
end
ylabel('{\itX}^{mode 1} / {\itX}^{mode 2}');

X = [];
Y1 = [];
Y2 = [];
JJ1 = [];
JJ2 = [];
for i = 1:N
  X = [X (i-0.5) (i+0.5)];
  Y1 = [Y1 dG1(ii(i)) dG1(ii(i))];
  Y2 = [Y2 dG2(ii(i)) dG2(ii(i))];
  JJ1 = [JJ1 J1(ii(i)) J1(ii(i))];
  JJ2 = [JJ2 J2(ii(i)) J2(ii(i))];
end

figure(2); clf; axes('position',[0.15 0.15 0.8 0.8]);
plot(X,Y1,'color','g','linewidth',2); hold on; 
plot(X,Y2,'color','b','linewidth',2); hold off;
set(gca,'Fontsize',18,'Xtick',1:n,'XtickLabel',[]);
axis([0 (N+1) -30 30]);
for i = 1:N
  t = text(i,-31,genes(ii(i)),'Rotation',-90,...
      'Fontsize',8);
end
ylabel('\Delta{\itG^{,}} , kcal mol^{-1}');
legend('Mode 1','Mode 2')

figure(3); clf; axes('position',[0.15 0.15 0.8 0.8]);
plot(X,JJ1,'color','g','linewidth',2); hold on; 
plot(X,JJ2,'color','b','linewidth',2); hold off;
l = legend('Mode 1','Mode 2',2);
set (l,'Fontsize',18);
set(gca,'Fontsize',18,'Xtick',1:n,'XtickLabel',[]);
set(gca,'Ytick',-4:2:4); set(gca,'Ytick',-5:2.5:5);
axis([0 (N+1) -5 5]);
for i = 1:N
  t = text(i,-5*31/30,genes(ii(i)),'Rotation',-90,...
      'Fontsize',8);
end
ylabel('{\itJ}, {\mu}mol min^{-1} g^{-1}');
