function [species,enzymes,genes,reversibility,S,EC] = ...
         read_bcn_file(filename)

species = [];
enzymes = [];
genes = [];
reversibility = [];
EC = [];

sfile = textread(filename,'%s');
readreactions = 0;
startflag = 0;
index = 0;
while ~(startflag)
  index = index + 1;
  string_i = sfile(index,:);
  if strcmp(string_i,'REACTIONLIST') 
    startflag = 1;
  end
end

stopflag = 0;
rxn_num = 0;
while ~(stopflag)

  rxn_num = rxn_num + 1;
  rxn_name = [];
    
% (1) Read reaction name    
  readrxn = 1;
  while readrxn
    index = index + 1;
    string_i = sfile(index,:);
    clist =  char(string_i); 
    Nc = length(clist);
    c_first = clist(1); c_end = clist(Nc);   
    if strcmp(c_first,'"')*strcmp(c_end,'"')
      sub_rxn_name = clist(2:Nc-1);
      readrxn = 0;
    end
    if strcmp(c_first,'"')*~strcmp(c_end,'"')
      sub_rxn_name = clist(2:Nc);
    end
    if ~strcmp(c_first,'"')*~strcmp(c_end,'"')
      sub_rxn_name = [' ' clist(1:Nc)];
    end
    if ~strcmp(c_first,'"')*strcmp(c_end,'"')
      sub_rxn_name = [' ' clist(1:Nc-1)];
      readrxn = 0;
    end
    rxn_name = [rxn_name sub_rxn_name];
  end
  enzymes = [enzymes
             cellstr(rxn_name)];      
             
% (2) Read gene name
  index = index + 1;
  genes = [genes
            sfile(index,:)];
        
% (3) Read reaction substrates
  readsub = 1;
  while readsub     
    index = index + 1;
    string_i = sfile(index,:);
% Get species name and stoichiometric number for current species:
    if isnumeric(str2num(strvcat(string_i)))*size(str2num(strvcat(string_i)))
      s = str2num(char(string_i));
      index = index + 1;
      species_i = sfile(index,:);
    else
      s = 1;
      species_i = string_i;
    end
% Check to see if species is in list
    [n,m] = size(species);
    new_species = 1;
    for i = 1:n
      if strcmp(species_i,species(i,:))
         new_species = 0;
         species_num = i;
      end
    end
    if new_species
      species = [species
                 species_i];
      species_num = n+1;
    end
% Update S matrix
    S(species_num,rxn_num) = -s;
     
    index = index + 1;
    string_i = sfile(index,:);
    if strcmp(string_i,'=')
      readsub = 0;
      reversibility(rxn_num) = 1;
    elseif strcmp(string_i,'>')
      readsub = 0;
      reversibility(rxn_num) = 0;
    end   
  end 
     
 % (4) Read reaction products
  readsub = 1;
  while readsub     
    index = index + 1;
    string_i = sfile(index,:);
% Get species name and stoichiometric number for current species:                 
    if isnumeric(str2num(strvcat(string_i)))*size(str2num(strvcat(string_i)))
      s = str2num(char(string_i));
      index = index + 1;
      species_i = sfile(index,:);
    else
      s = 1;
      species_i = string_i;
    end

% Check to see if species is in list
    [n,m] = size(species);
    new_species = 1;
    for i = 1:n
      if strcmp(species_i,species(i,:))
         new_species = 0;
         species_num = i;
      end
    end
    if new_species
      species = [species
                 species_i];
      species_num = n+1;
    end
% Update S matrix
    S(species_num,rxn_num) = +s;
     
    index = index + 1;
    string_i = sfile(index,:);
    clist =  char(string_i);
    if strcmp(clist(1),'"')
      readsub = 0;
    end   
  end 
 
% (5) Read EC number
  index = index - 1;
  EC_name = [];
  readEC = 1;
  while readEC
    index = index + 1;
    string_i = sfile(index,:);
    clist =  char(string_i); 
    Nc = length(clist);
    c_first = clist(1); c_end = clist(Nc);   
    if strcmp(c_first,'"')*strcmp(c_end,'"')
      sub_EC_name = clist(2:Nc-1);
      readEC = 0;
    end
    if strcmp(c_first,'"')*~strcmp(c_end,'"')
      sub_EC_name = clist(2:Nc);
    end
    if ~strcmp(c_first,'"')*~strcmp(c_end,'"')
      sub_EC_name = [' ' clist(1:Nc)];
    end
    if ~strcmp(c_first,'"')*strcmp(c_end,'"')
      sub_EC_name = [' ' clist(1:Nc-1)];
      readEC = 0;
    end
    EC_name = [EC_name sub_EC_name];
  end
  EC = [EC
        cellstr(EC_name)];
     
  if strcmp(sfile(index+1,:),'EOF') 
    stopflag = 1;
  end

end

